==> babel-plugin-react-intl-auto-2.2.0.tgz: package/lib/__tests__/hook.test.js <==
"use strict";

var _path = _interopRequireDefault(require("path"));

var _babelPluginTester = _interopRequireDefault(require("babel-plugin-tester"));

var _ = _interopRequireDefault(require(".."));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var filename = _path.default.resolve(__dirname, '..', '__fixtures__', 'messages.js');

var defaultTest = {
  title: 'with useIntl hook imported',
  code: `
import { useIntl } from 'react-intl';

intl.formatMessage({ defaultMessage: "hello" });
  `
};
var multiUseTest = {
  title: 'multiple uses',
  code: `
import { useIntl } from 'react-intl';

intl.formatMessage({ defaultMessage: "hello" });
intl.formatMessage({ defaultMessage: "hello" });
intl.formatMessage({ defaultMessage: "some other message" });
`
};
var withValueInMessageTest = {
  title: 'with a value interpolated in the message',
  code: `
import { useIntl } from 'react-intl';

intl.formatMessage({ defaultMessage: \`template string ${1 + 1}\` });
`
};
var withVariableMessageTest = {
  title: 'with a variable as the defaultMessage',
  code: `
import { useIntl } from 'react-intl';

const message = "variable message";

intl.formatMessage({ defaultMessage: message });
`
};
var withCustomProperties = {
  title: 'with custom properties in formatMessage call',
  code: `
import { useIntl } from 'react-intl';

intl.formatMessage({ defaultMessage: "custom prop", other: 123 });
`
};
var someSupportedUseCases = {
  title: 'some supported use cases',
  code: `
import { useIntl } from 'react-intl';

const Component2 = () => {
  const intl = useIntl();
  const label = intl.formatMessage({ defaultMessage: "hello" });
  return (
    <button aria-label={intl.formatMessage({ defaultMessage: "hello" })}>
      {intl.formatMessage({ defaultMessage: "hello" })}
    </button>
  );
};
  `
};
var importAsTest = {
  title: 'with FormattedMessage imported as something else',
  code: `
import { useIntl as i18n } from 'react-intl';

intl.formatMessage({ defaultMessage: "i18n" });
`
};
var throwWhenNotAnalyzableTest = {
  title: 'throws if defaultMessage isn’t analyzable',
  code: `
import { useIntl } from 'react-intl';
const getMsg = () => 'hello';
intl.formatMessage({
  defaultMessage: getMsg(),
});
`,
  error: /\[React Intl Auto\] defaultMessage must be statically evaluate\x2Dable for extraction/,
  snapshot: false
};
var notTransformIfNotImportedTest = {
  title: 'does nothing if react-intl is not imported',
  snapshot: false,
  code: `
import any from 'any-module';
intl.formatMessage({
  defaultMessage: "hello"
});
`
};
var notTransformIfIdIsProvided = {
  title: 'does nothing if id is already provided',
  snapshot: false,
  code: `
import { useIntl } from 'react-intl';
intl.formatMessage({
  id: "my.custom.id",
  defaultMessage: "hello"
});
`
};
var tests = [defaultTest, multiUseTest, withValueInMessageTest, withVariableMessageTest, withCustomProperties, someSupportedUseCases, importAsTest, throwWhenNotAnalyzableTest, notTransformIfNotImportedTest, notTransformIfIdIsProvided];
cases([{
  title: 'default',
  tests
}, {
  title: 'removePrefix = "src"',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: 'src'
  }
}, {
  title: 'removePrefix = "src/" -- with slash',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: 'src/'
  }
}, {
  title: 'filebase = true',
  tests: [defaultTest],
  pluginOptions: {
    filebase: true
  }
}, // {
//   title: 'includeExportName = true',
//   tests: [defaultTest],
//   pluginOptions: { includeExportName: true },
// },
// {
//   title: 'includeExportName = all',
//   tests: [defaultTest],
//   pluginOptions: { includeExportName: 'all' },
// },
// {
//   title: 'removePrefix = true, includeExportName = true',
//   tests: [defaultTest],
//   pluginOptions: { removePrefix: true, includeExportName: true },
// },
{
  title: 'removePrefix = false',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: false
  }
}, // {
//   title: 'removePrefix = true, includeExportName = all',
//   tests: [defaultTest],
//   pluginOptions: { removePrefix: true, includeExportName: 'all' },
// },
// {
//   title: 'extractComments = false',
//   tests: [defaultTest],
//   pluginOptions: { extractComments: false },
// },
{
  title: 'removePrefix = /__fixtures__/',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: /[\/\\]__fixtures__/
  }
}, {
  title: 'removePrefix = "src.__fixtures__"',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: 'src.__fixtures__'
  }
}]);

function cases(testCases) {
  var defaultOpts = {
    title: '',
    plugin: _.default,
    snapshot: true,
    babelOptions: {
      filename,
      parserOpts: {
        plugins: ['jsx']
      }
    },
    tests: [] // Apparently a bug in eslint
    // eslint-disable-next-line no-unused-vars

  };
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = testCases[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var testCase = _step.value;
      testCase.tests = testCase.tests.map(function (t) {
        return _objectSpread({}, t, {
          title: t.title
        });
      });
      (0, _babelPluginTester.default)(_objectSpread({}, defaultOpts, {}, testCase));
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return != null) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }
}

==> babel-plugin-react-intl-auto-3.0.0.tgz: package/lib/__tests__/hook.test.js <==
"use strict";

var _path = _interopRequireDefault(require("path"));

var _testUtils = require("../utils/testUtils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const filename = _path.default.resolve(__dirname, '..', '__fixtures__', 'messages.js');

const defaultTest = {
  title: 'with useIntl hook imported',
  code: `
import { useIntl } from 'react-intl';

intl.formatMessage({ defaultMessage: "hello" });
  `
};
const multiUseTest = {
  title: 'multiple uses',
  code: `
import { useIntl } from 'react-intl';

intl.formatMessage({ defaultMessage: "hello" });
intl.formatMessage({ defaultMessage: "hello" });
intl.formatMessage({ defaultMessage: "some other message" });
`
};
const withValueInMessageTest = {
  title: 'with a value interpolated in the message',
  code: `
import { useIntl } from 'react-intl';

intl.formatMessage({ defaultMessage: \`template string ${1 + 1}\` });
`
};
const withVariableMessageTest = {
  title: 'with a variable as the defaultMessage',
  code: `
import { useIntl } from 'react-intl';

const message = "variable message";

intl.formatMessage({ defaultMessage: message });
`
};
const withCustomProperties = {
  title: 'with custom properties in formatMessage call',
  code: `
import { useIntl } from 'react-intl';

intl.formatMessage({ defaultMessage: "custom prop", other: 123 });
`
};
const someSupportedUseCases = {
  title: 'some supported use cases',
  code: `
import { useIntl } from 'react-intl';

const Component2 = () => {
  const intl = useIntl();
  const label = intl.formatMessage({ defaultMessage: "hello" });
  return (
    <button aria-label={intl.formatMessage({ defaultMessage: "hello" })}>
      {intl.formatMessage({ defaultMessage: "hello" })}
    </button>
  );
};
  `
};
const importAsTest = {
  title: 'with FormattedMessage imported as something else',
  code: `
import { useIntl as i18n } from 'react-intl';

intl.formatMessage({ defaultMessage: "i18n" });
`
};
const throwWhenNotAnalyzableTest = {
  title: 'throws if defaultMessage isn’t analyzable',
  code: `
import { useIntl } from 'react-intl';
const getMsg = () => 'hello';
intl.formatMessage({
  defaultMessage: getMsg(),
});
`,
  error: /\[React Intl Auto\] defaultMessage must be statically evaluate\x2Dable for extraction/u,
  snapshot: false
};
const notTransformIfNotImportedTest = {
  title: 'does nothing if react-intl is not imported',
  snapshot: false,
  code: `
import any from 'any-module';
intl.formatMessage({
  defaultMessage: "hello"
});
`
};
const notTransformIfIdIsProvided = {
  title: 'does nothing if id is already provided',
  snapshot: false,
  code: `
import { useIntl } from 'react-intl';
intl.formatMessage({
  id: "my.custom.id",
  defaultMessage: "hello"
});
`
};
const tests = [defaultTest, multiUseTest, withValueInMessageTest, withVariableMessageTest, withCustomProperties, someSupportedUseCases, importAsTest, throwWhenNotAnalyzableTest, notTransformIfNotImportedTest, notTransformIfIdIsProvided];
(0, _testUtils.cases)(filename, [{
  title: 'default',
  tests
}, {
  title: 'removePrefix = "src"',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: 'src'
  }
}, {
  title: 'removePrefix = "src/" -- with slash',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: 'src/'
  }
}, {
  title: 'filebase = true',
  tests: [defaultTest],
  pluginOptions: {
    filebase: true
  }
}, // {
//   title: 'includeExportName = true',
//   tests: [defaultTest],
//   pluginOptions: { includeExportName: true },
// },
// {
//   title: 'includeExportName = all',
//   tests: [defaultTest],
//   pluginOptions: { includeExportName: 'all' },
// },
// {
//   title: 'removePrefix = true, includeExportName = true',
//   tests: [defaultTest],
//   pluginOptions: { removePrefix: true, includeExportName: true },
// },
{
  title: 'removePrefix = false',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: false
  }
}, // {
//   title: 'removePrefix = true, includeExportName = all',
//   tests: [defaultTest],
//   pluginOptions: { removePrefix: true, includeExportName: 'all' },
// },
// {
//   title: 'extractComments = false',
//   tests: [defaultTest],
//   pluginOptions: { extractComments: false },
// },
{
  title: 'removePrefix = /__fixtures__/',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: /[\/\\]__fixtures__/u
  }
}, {
  title: 'removePrefix = "src.__fixtures__"',
  tests: [defaultTest],
  pluginOptions: {
    removePrefix: 'src.__fixtures__'
  }
}]);
